@@ -51,7 +51,7 @@
 rankIPLBatsmen <- function(dir='.',odir=".",minMatches=50) {
 
     currDir= getwd()
-    teams <-c("Chennai Super Kings","Deccan Chargers","Delhi Daredevils",
+    teams <-c("Chennai Super Kings","Delhi Capitals", "Deccan Chargers","Delhi Daredevils",
               "Kings XI Punjab", 'Kochi Tuskers Kerala',"Kolkata Knight Riders",
               "Mumbai Indians", "Pune Warriors","Rajasthan Royals",
               "Royal Challengers Bangalore","Sunrisers Hyderabad","Gujarat Lions",
