@@ -48,7 +48,7 @@
 
 saveAllMatchesAllOppositionIPLT20 <- function(dir=".",odir=".") {
 
-    teams <-c("Chennai Super Kings","Deccan Chargers","Delhi Daredevils",
+    teams <-c("Chennai Super Kings","Delhi Capitals","Deccan Chargers","Delhi Daredevils",
               "Kings XI Punjab", 'Kochi Tuskers Kerala',"Kolkata Knight Riders",
               "Mumbai Indians", "Pune Warriors","Rajasthan Royals",
               "Royal Challengers Bangalore","Sunrisers Hyderabad","Gujarat Lions",
